<?php class Consignee extends Person
{	

	function exists($person_id)
	{
		$this->db->from('consignees');	
		$this->db->join('people', 'people.person_id = consignees.person_id');
		$this->db->where('consignees.person_id',$person_id);
		$query = $this->db->get();
		
	return ($query->num_rows()==1);
	}
	
	function account_number_exists($account_number)
	{
		$this->db->from('consignees');	
		$this->db->where('consignees.account_number',$account_number);
		$query = $this->db->get();
		
	return ($query->num_rows()==1);
	}

	function bisoft_id_exists($bisoft_id)
	{
		$this->db->from('consignees');	
		$this->db->where('consignees.bisoft_id',$bisoft_id);
		$query = $this->db->get();
	return ($query->num_rows()==1);
	}


	function get_max_bisoft_id()
	{
		$this->db->select('max(bisoft_id) as max_bisoft', false);
		$this->db->from('consignees');
		$rezult = $this->db->get()->result_array();
	return $rezult['0']['max_bisoft'];
	}

	/* Returns all the consignees */
	function get_all()
	{
		$this->db->from('consignees');
		$this->db->join('people','consignees.person_id=people.person_id');
		$this->db->where('deleted',0);
		$this->db->order_by("company_name", "asc");
	return $this->db->get();		
	}
	
	/* Returns all the consignees */
	function get_all_dropdown()
	{
		$this->db->from('consignees');		
		$this->db->where('deleted',0);
		$this->db->order_by('bisoft_id', "asc");
	return $this->db->get();		
	}
	
	function count_all()
	{
		$this->db->from('consignees');
		$this->db->where('deleted',0);
		return $this->db->count_all_results();
	}
	
	/*	Gets information about a particular consignee */
	function get_info($person_id)
	{
		$this->db->from('consignees');	
		$this->db->join('people', 'people.person_id = consignees.person_id');
		$this->db->where('consignees.person_id',$person_id);
		$query = $this->db->get();
		
		if($query->num_rows()==1)
		{
			return $query->row();
		}
		else
		{
			//Get empty base parent object, as $person_id is NOT an consignee
			$person_obj=parent::get_info(-1);
			
			//Get all the fields from consignee table
			$fields = $this->db->list_fields('consignees');
			
			//append those fields to base parent object, we we have a complete empty object
			foreach ($fields as $field)
            { $person_obj->$field='';}
			return $person_obj;
		}
	}
	
	/*	Gets information about multiple consignees */
	function get_multiple_info($person_ids)
	{
		$this->db->from('consignees');
		$this->db->join('people', 'people.person_id = consignees.person_id');		
		$this->db->where_in('consignees.person_id',$person_ids);
		$this->db->order_by("company_name", "asc");
		return $this->db->get();		
	}
	

	function get_info_by_bisoft_id($bisoft_id)
	{
		$this->db->from('consignees');	
		$this->db->where('consignees.bisoft_id',$bisoft_id);
		$query = $this->db->get();	
		if($query->num_rows()==1) 
			{ return $query->row(); }
		else 
			{ return 0; }
	}

	function get_consi_name($bisoft_id)
	{
		$this->db->from('consignees');
		$this->db->where('consignees.bisoft_id',$bisoft_id);
		$this->db->where('deleted',0);
		$query = $this->db->get();
		
		if($query->num_rows()==1)
			{ return $query->row()->company_name;}
		else	
			{ return ''; }	
	}


	/* Inserts or updates a consignee */
	function save( &$person_data, &$consignee_data, $person_id)
	{
		$success=false;
		//Run these queries as a transaction, we want to make sure we do all or nothing
		$this->db->trans_start();
		
		if(parent::save_person( $person_data, $person_id))
		{
			if (!$person_id or !$this->exists($person_id))
			{
				$consignee_data['person_id'] = $person_data['person_id'];
				$success = $this->db->insert('consignees', $consignee_data);				
			}
			else
			{
				$this->db->where('person_id', $person_id);
				$success = $this->db->update('consignees', $consignee_data);
			}
		}
		
	$this->db->trans_complete();		
	return $success;
	}
	
	/*	Deletes one consignee */
	function delete($consignee_id)
	{
		$this->db->where('person_id', $consignee_id);
		return $this->db->update('consignees', array('deleted' => 1));
	}
	
	/*	Deletes a list of consignees */
	function delete_list($consignee_ids)
	{
		$this->db->where_in('person_id',$consignee_ids);
		return $this->db->update('consignees', array('deleted' => 1));
 	}
 	
 	/* Get search suggestions to find consignees */
	function get_search_suggestions($search,$limit=50)
	{
		$suggestions = array();
		$this->db->from('consignees');
		$this->db->join('people','consignees.person_id=people.person_id');	
		$this->db->where('deleted', 0);
		$this->db->like("company_name",$search);
		$this->db->order_by("company_name", "asc");		
		$by_company_name = $this->db->get();
		foreach($by_company_name->result() as $row)
			{$suggestions[]=$row->person_id.'|'.$row->company_name;}

		$this->db->from('consignees');
		$this->db->join('people','consignees.person_id=people.person_id');	
		$this->db->where("(first_name LIKE '%".$this->db->escape_like_str($search)."%' or 
		last_name LIKE '%".$this->db->escape_like_str($search)."%' or 
		CONCAT(`first_name`,' ',`last_name`) LIKE '%".$this->db->escape_like_str($search)."%') and deleted=0");
		$this->db->order_by("last_name", "asc");		
		$by_name = $this->db->get();
		foreach($by_name->result() as $row)
			{$suggestions[]=$row->company_name.' <i>('.$row->first_name.' '.$row->last_name.')</i>';}

		// only return $limit suggestions
		if(count($suggestions) > $limit)
			{ $suggestions = array_slice($suggestions, 0, $limit); }
			
		return $suggestions;
	}
	
	/*	Get search suggestions to find consignees */
	function get_consignee_search_suggestions($search,$limit=50)
	{
		$suggestions = array();
		$this->db->from('consignees');
		$this->db->join('people','consignees.person_id=people.person_id');	
		$this->db->where('deleted', 0);
		$this->db->like("company_name",$search);
		$this->db->order_by("company_name", "asc");		
		$by_company_name = $this->db->get();
		
		foreach($by_company_name->result() as $row)
			{ $suggestions[]=$row->person_id.'|'.$row->company_name.' <i>('.$row->first_name.' '.$row->last_name.')</i>'; }

		$this->db->from('consignees');
		$this->db->join('people','consignees.person_id=people.person_id');	
		$this->db->where("(first_name LIKE '%".$this->db->escape_like_str($search)."%' or 
		last_name LIKE '%".$this->db->escape_like_str($search)."%' or 
		CONCAT(`first_name`,' ',`last_name`) LIKE '%".$this->db->escape_like_str($search)."%') and deleted=0");
		$this->db->order_by("last_name", "asc");		
		$by_name = $this->db->get();
		foreach($by_name->result() as $row)
			{ $suggestions[]=$row->person_id.'|'.$row->first_name.' '.$row->last_name.' <i>['.$row->company_name.']</i>'; }

		// only return $limit suggestions
		if(count($suggestions) > $limit)
			{ $suggestions = array_slice($suggestions, 0, $limit); }
		
		return $suggestions;
	}
	
	/*	Preform a search on consignees */
	function search($search)
	{
		$this->db->from('consignees');
		$this->db->join('people','consignees.person_id=people.person_id');		
		$this->db->where("(first_name LIKE '%".$this->db->escape_like_str($search)."%' or 
		last_name LIKE '%".$this->db->escape_like_str($search)."%' or 
		company_name LIKE '%".$this->db->escape_like_str($search)."%' or 
		CONCAT(`first_name`,' ',`last_name`) LIKE '%".$this->db->escape_like_str($search)."%') and deleted=0");		
		$this->db->order_by("last_name", "asc");
		return $this->db->get();	
	}

}
?>
