<?php

class Customer extends Person
{	
	/*	Determines if a given person_id is a customer */
	function exists($person_id)
	{
		$this->db->from('customers');	
		$this->db->join('people', 'people.person_id = customers.person_id');
		$this->db->where('customers.person_id',$person_id);
		$query = $this->db->get();
		return ($query->num_rows()==1);
	}
	
	function account_number_exists($account_number)
	{
		$this->db->from('customers');	
		$this->db->where('customers.account_number',$account_number);
		$query = $this->db->get();
		return ($query->num_rows()==1);
	}

	function get_max_bisoft_id()
	{
		$this->db->select('max(bisoft_id) as max_bisoft', false);
		$this->db->from('customers');
	//	$this->db->where('deleted',0);
		$rezult = $this->db->get()->result_array();
	return $rezult['0']['max_bisoft'];
	}

	/*	Returns all the customers */
	function get_all($limit=10000, $offset=0)
	{
		$this->db->from('customers');
		$this->db->join('people','customers.person_id=people.person_id');			
		$this->db->where('deleted',0);
		$this->db->order_by("company_name", "asc");
	//	$this->db->order_by("rating", "desc");
		$this->db->limit($limit);
		$this->db->offset($offset);
		return $this->db->get();		
	}

	/* Returns all top customers */
	function get_all_top()
	{
		$this->db->from('customers');
		$this->db->join('people','customers.person_id=people.person_id');			
		$this->db->where('deleted',0);
		$this->db->where('rating > 1');
		$this->db->order_by("company_name", "acs");
	return $this->db->get();		
	}

	/* Returns all the customers */
	function get_all_dropdown()
	{
		$this->db->from('customers');
		$this->db->where('rating > 0');
		$this->db->where('deleted',0);
		$this->db->order_by("company_name", "asc");
	//	$this->db->order_by("rating", "desc");
	return $this->db->get();		
	}	
	
	/* Returns all the customers */
	function get_dropdown_1()
	{
		$this->db->from('customers');
		$this->db->where('rating > 50');
		$this->db->where('deleted',0);
		$this->db->order_by("company_name", "asc");
	return $this->db->get();		
	}
	
	function get_dropdown_2()
	{
		$this->db->from('customers');
		$this->db->where('rating > 0 AND rating <= 50');
		$this->db->where('deleted',0);
		$this->db->order_by("company_name", "asc");
	//	$this->db->order_by("rating", "desc");
	return $this->db->get();		
	}
	
	function get_all_online_clients()
	{
		$this->db->from('customers');
		$this->db->where('status in ("online", "onlineto")');
		$this->db->where('deleted',0);
		$this->db->order_by("company_name", "asc");
	return $this->db->get();		
	}
	
	function count_all()
	{
		$this->db->from('customers');
		$this->db->where('deleted',0);
		return $this->db->count_all_results();
	}
	
	/*	Gets information about a particular customer */
	function get_info($person_id)
	{
		$this->db->from('customers');	
		$this->db->join('people', 'people.person_id = customers.person_id');
		$this->db->where('customers.person_id',$person_id);
		$query = $this->db->get();
		
		if($query->num_rows()==1)
			{ return $query->row(); }
		else
			{  //Get empty base parent object, as $person_id is NOT a customer
				$person_obj=parent::get_info(-1);
				
				//Get all the fields from customer table
				$fields = $this->db->list_fields('customers');
				
				//append those fields to base parent object, we we have a complete empty object
				foreach ($fields as $field) {$person_obj->$field='';}
				
				return $person_obj;
			}
	}
	
	/* Gets information about multiple customers */
	function get_multiple_info($customer_ids)
	{
		$this->db->from('customers');
		$this->db->join('people', 'people.person_id = customers.person_id');		
		$this->db->where_in('customers.person_id',$customer_ids);
		$this->db->order_by("company_name", "asc");
		return $this->db->get();		
	}
	

	/*	Gets information about a particular customer by bisoft_id*/
	function bisoft_id_exists($bisoft_id)
	{
		$this->db->from('customers');	
		$this->db->where('customers.bisoft_id',$bisoft_id);
		$query = $this->db->get();
		return ($query->num_rows()==1);
	}


	function get_info_by_bisoft_id($bisoft_id)
	{
		$this->db->from('customers');	
		$this->db->where('customers.bisoft_id',$bisoft_id);
		$query = $this->db->get();
		if	( $query->num_rows()==1)
			{ return $query->row();}
		else	
			{ return false;}			
	}

	function get_customer_name($bisoft_id)
	{
		$this->db->from('customers');
		$this->db->where('customers.bisoft_id',$bisoft_id);
		$this->db->where('deleted',0);
		$query = $this->db->get();
		
		if($query->num_rows()==1)
			{ return $query->row()->company_name;}
		else	{return '';}	
	}
	
	
	/*	Inserts or updates a customer */
	function save(&$person_data, &$customer_data, $person_id)
	{	$success=false;
		$this->db->trans_start();
		if(parent::save_person($person_data,$person_id))
		{
			if (!$person_id or !$this->exists($person_id))
			{  $customer_data['person_id'] = $person_data['person_id'];
				$success = $this->db->insert('customers',$customer_data);				
			}
			else
			{  $this->db->where('person_id', $person_id);
				$success = $this->db->update('customers',$customer_data);
			}
		}
	$this->db->trans_complete();		
	return $success;
	}
	
	/* Deletes one customer */
	function delete($person_id)
	{
		$this->db->where('person_id', $person_id);
		return $this->db->update('customers', array('deleted' => 1));
	}
	
	/* Deletes a list of customers */
	function delete_list($persons_ids)
	{
		$this->db->where_in('person_id',$persons_ids);
		return $this->db->update('customers', array('deleted' => 1));
 	}
 	
 	
 	/* ==================== Change Brands ==================== */
 	function get_vedom_by_client($vedom,$client_id)
 	{
		$this->db->from($vedom);
		$this->db->where('client_id',$client_id);
		$this->db->where("mode_id in ('E', 'BE', 'F', 'Ki', 'Di', 'KPr', 'KRz')");
		$this->db->where('location',0);
 		$this->db->where('deleted',0);
		$query = $this->db->get();
		if($query->num_rows()>0) 
			{ return $query->result_array();}
		else { return 0;}	
 	} 	
 	
 	
 	function change_brand($vedom,$doc_id,$customer_data)
 	{
		if($vedom and $customer_data)
			{ 
				$this->db->where('doc_id',$doc_id);
				$success = $this->db->update($vedom,$customer_data);
				$this->db->where('doc_id',$doc_id);
				$success = $this->db->update($vedom.'_items',$customer_data);
				return $success;
			}
		else
			{ return 0; }
 	} 	
 	

 	/* ==================== JOINT CLIENTS ==================== */
 	function get_joint($bisoft_id)
 	{
		$this->db->from('customers');
		$this->db->where('bisoft_id',$bisoft_id);
 		$this->db->where('deleted',0);
		$query = $this->db->get();
		if($query->num_rows()==1) 
			{ return $query->row()->joint;}
		else { return 0;}	
 	}

	function get_joint_customers($bisoft_id)
	{
		$this->db->from('customers');
		$this->db->where('joint',$bisoft_id);
		$this->db->where('deleted',0);
		$query = $this->db->get();
		if($query->num_rows()>0)
			{ return $query->result_array();} // ->row()
		else { return 0;}	
	} 	
 	
 	
 	/*	Get search suggestions to find customers */
	function get_search_suggestions($search,$limit=100)
	{
		$suggestions = array();
		$this->db->from('customers');
		$this->db->join('people','customers.person_id=people.person_id');	
		$this->db->where('deleted', 0);
		$this->db->like("company_name",$search);
		$this->db->order_by("company_name", "asc");		
		$by_company_name = $this->db->get();
		foreach($by_company_name->result() as $row)
			{ $suggestions[]=$row->company_name; } // .' <i>('.$row->first_name.' '.$row->last_name.')</i>'

		//only return $limit suggestions
		if(count($suggestions) > $limit)
			{ $suggestions = array_slice($suggestions, 0, $limit); }
			
		return $suggestions;
	}
	
	/* Get search suggestions to find customers */
	function get_customer_search_suggestions($search,$limit=100,$invoice=0)
	{
		$suggestions = array();
		$this->db->from('customers');
		$this->db->join('people','customers.person_id=people.person_id');	
		$this->db->where('deleted', 0);
		if(!$invoice) {$this->db->where('status != "invoice"');}

		$this->db->like("account_number",$search);
		$this->db->order_by("company_name", "asc");		
		$by_company_name = $this->db->get();
		
		foreach($by_company_name->result() as $row)
			{ $suggestions[]=$row->person_id.'|'.$row->account_number.' '.$row->company_name; }

		if(count($suggestions)==0)
		{
			$this->db->from('customers');
			$this->db->join('people','customers.person_id=people.person_id');	
			$this->db->where('deleted', 0);
			$this->db->like("company_name",$search);
			$this->db->order_by("company_name", "asc");		
			$by_company_name = $this->db->get();
			
			foreach($by_company_name->result() as $row)
				{ $suggestions[]=$row->person_id.'|'.$row->account_number.' '.$row->company_name; }
			
			if(count($suggestions)==0)
			{
				$this->db->from('customers');
				$this->db->join('people','customers.person_id=people.person_id');	
				$this->db->where("(first_name LIKE '%".$this->db->escape_like_str($search)."%' or 
										last_name LIKE '%".$this->db->escape_like_str($search)."%' or 
										account_number LIKE '%".$this->db->escape_like_str($search)."%' or 
				CONCAT(`first_name`,' ',`last_name`) LIKE '%".$this->db->escape_like_str($search)."%') and deleted=0");
				$this->db->order_by("last_name", "asc");		
				$by_name = $this->db->get();
				
				foreach($by_name->result() as $row)
					{ $suggestions[]=$row->person_id.'|'.$row->first_name.' '.$row->last_name." <i>/ ".$row->company_name."</i>"; }
			}
		}
			
		// only return $limit suggestions
		if(count($suggestions) > $limit)
			{ $suggestions = array_slice($suggestions, 0, $limit); }
		
		return $suggestions;
	}
	
	/*	Preform a search on customers */
	function search($search)
	{
		$this->db->from('customers');
		$this->db->join('people','customers.person_id=people.person_id');		
		$this->db->where("(first_name LIKE '%".$this->db->escape_like_str($search)."%' or 
		last_name LIKE '%".$this->db->escape_like_str($search)."%' or 
		company_name LIKE '%".$this->db->escape_like_str($search)."%' or 
		CONCAT(`first_name`,' ',`last_name`) LIKE '%".$this->db->escape_like_str($search)."%') and deleted=0");		
		$this->db->order_by("company_name", "asc");
		return $this->db->get();	
	}

} ?>
