<?php
require_once("Report.php");
class Invoice_table extends Report
{
	function __construct()
	{
		parent::__construct();
	}
	
	public function getDataColumns()
	{
		return array(
					$this->lang->line('reports_invoice_id'),
					$this->lang->line('reports_date'),
					$this->lang->line('reports_document'),
					$this->lang->line('reports_customer'),
					$this->lang->line('common_account_number'),
					$this->lang->line('reports_suma'),
					$this->lang->line('reports_invoice_vat'),
					$this->lang->line('reports_subtotal'),
					$this->lang->line('reports_free_bills'),
					$this->lang->line('reports_export_no_vat'),
					$this->lang->line('reports_export_vat'),
					$this->lang->line('reports_comments')
					);
	}
	
	public function getData(array $inputs)
	{
	$invoices = 'V'.date('ym', strtotime( $inputs['end_date'] ));

		$this->db->select('	
				doc_id, 
				mode,
				mode_id,
				doc_number, 
				doc_date,
				total_qty, 
				total_sum, 
				total_discount,
				taxed,
				total_taxes,
				pay_group,
				pay_type,
				pay_amount,
				client_id, 
				client, 
				employee_id,
				employee,
				comment,
				location',	false);

		$this->db->from($invoices);
		$this->db->where('doc_date BETWEEN "'. $inputs['start_date']. '" and "'. $inputs['end_date'].'"');
		$this->db->where('deleted = 0');

			switch ($inputs['sale_type']) 
				{
				case 'all': $this->db->where('mode_id in ("F", "Ki", "Di", "Pr")');	break;
				case 'invoice':		$this->db->where('mode_id = "F"');	break;
				case 'invoice_ki':	$this->db->where('mode_id = "Ki"');	break;
				case 'invoice_di':	$this->db->where('mode_id = "Di"');	break;
				case 'invoice_pr':	$this->db->where('mode_id = "Pr"');	break;
				}

		$this->db->group_by('doc_id');
		$this->db->order_by('doc_number');

	return $data['summary'] = $this->db->get()->result_array();
	}

	// Сумарна информация ...............
	public function getSummaryData(array $inputs)
	{
	$invoices = 'V'.date('ym', strtotime( $inputs['end_date'] ));

		$this->db->select('
				sum(total_sum) as subtotal, 
				sum(total_taxes) as vat,
				sum(pay_amount) as total');

		$this->db->from($invoices);
		$this->db->where('doc_date BETWEEN "'. $inputs['start_date']. '" and "'. $inputs['end_date'].'"');
		$this->db->where('deleted = 0');

			switch ($inputs['sale_type']) 
				{
				case 'all': $this->db->where('mode_id in ("F", "Ki", "Di", "Pr")');	break;
				case 'invoice':		$this->db->where('mode_id = "F"');	break;
				case 'invoice_ki':	$this->db->where('mode_id = "Ki"');	break;
				case 'invoice_di':	$this->db->where('mode_id = "Di"');	break;
				case 'invoice_pr':	$this->db->where('mode_id = "Pr"');	break;
				}
		
	return $this->db->get()->row_array();
	}


/* ======================================= EXPORT ===================================== */
	public function getExportColumns()
	{
		return array(
					'ID на док.', 	// 1
					'Дата опер.', 	// 2
					'Тип док.',		// 3
					'Номер док.',	// 4
					'Дата док.',	// 5
					'Код контр.',	// 6
					'Име контр.',	// 7
					'Булстат',		// 8
					'ИН по ДДС',	// 9
					'Код държ.',	// 10
					'Пощ.код',		// 11 K
					'Град',			// 12 L
					'Адрес',			// 13 M
		'Вид разход по ЗДДС',	// 14 N
			'Начин на плащане',	// 15 O
		'Коментар за предмет на сделката по ДДС',	// 16 P
					'ДДС %',			// 17 Q

				// За продажба на стока
				'Сума без ДДС',	// 18 R 2
					'Сума ТО',		// 19 S 2
		'Сума без ДДС-сума ТО',	// 20 T 2
					'Сума ДДС ',	// 21 U 2
		'Сума без ДДС-сума ТО+сума ДДС',	// 22 V 2

				// За извършени услуги
				'Сума без ДДС',	// 23 W 2
					'Сума ТО',		// 24 X 2
		'Сума без ДДС-сума ТО',	// 25 Y 2
					'Сума ДДС ',	// 26 Z 2
		'Сума без ДДС-сума ТО+сума ДДС',	// 27 AA 2

					'ТО %'			// 28 AB END
					);
	}
	
	public function getExportData(array $inputs)
	{
	$invoices = 'V'.date('ym', strtotime( $inputs['end_date'] ));

		$this->db->select('	
				doc_id, 
				mode,
				mode_id,
				doc_number, 
				doc_date,
				total_qty, 
				total_sum, 
				total_discount,
				taxed,
				total_taxes,
				pay_group,
				pay_type,
				pay_amount,
				client_id, 
				client, 
				employee_id,
				employee,
				comment,
				location',	false);

		$this->db->from($invoices);
		$this->db->where('doc_date BETWEEN "'. $inputs['start_date']. '" and "'. $inputs['end_date'].'"');
		$this->db->where('deleted = 0');

			switch ($inputs['sale_type']) 
				{
				case 'all': $this->db->where('mode_id in ("F", "Ki", "Di", "Pr")');	break;
				case 'invoice':		$this->db->where('mode_id = "F"');	break;
				case 'invoice_ki':	$this->db->where('mode_id = "Ki"');	break;
				case 'invoice_di':	$this->db->where('mode_id = "Di"');	break;
				case 'invoice_pr':	$this->db->where('mode_id = "Pr"');	break;
				}

		$this->db->group_by('doc_id');
		$this->db->order_by('doc_number');

	return $this->db->get()->result_array();
	}


}
?>
